@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  Alleyoop
- *  Copyright (C) 2003-2006 Jeffrey Stedfast
+ *  Copyright (C) 2003-2009 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -116,7 +116,6 @@ alleyoop_init (Alleyoop *grind)
 {
 	grind->argv = NULL;
 	grind->srcdir = NULL;
-	grind->symtab = NULL;
 	
 	grind->view = NULL;
 	
@@ -139,9 +138,6 @@ alleyoop_finalize (GObject *obj)
 	if (grind->gio)
 		g_io_channel_unref (grind->gio);
 	
-	if (grind->symtab)
-		symtab_free (grind->symtab);
-	
 	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
@@ -548,7 +544,7 @@ help_about_cb (GtkWidget *widget, gpointer user_data)
 	
 	grind = (Alleyoop *) user_data;
 	if (grind->about == NULL) {
-		grind->about = gnome_about_new ("Alleyoop", VERSION, "Copyright 2003-2006 Jeffrey Stedfast <fejj@novell.com>",
+		grind->about = gnome_about_new ("Alleyoop", VERSION, "Copyright 2003-2009 Jeffrey Stedfast <fejj@novell.com>",
 						_("Alleyoop is a Valgrind front-end for the GNOME environment."),
 						(const char **) authors, NULL, _(translation), NULL);
 		
@@ -669,21 +665,6 @@ prefs_delete_event (GtkWidget *widget, gpointer user_data)
 	return TRUE;
 }
 
-static SymTab *
-load_symtab (const char *progname)
-{
-	SymTab *symtab;
-	char *filename;
-	
-	if (!(filename = vg_tool_view_scan_path (progname)))
-		return NULL;
-	
-	symtab = symtab_new (filename);
-	g_free (filename);
-	
-	return symtab;
-}
-
 GtkWidget *
 alleyoop_new (const char *tool, const char **argv, const char **srcdir)
 {
@@ -708,9 +689,6 @@ alleyoop_new (const char *tool, const char **argv, const char **srcdir)
 	grind->argv = argv;
 	grind->srcdir = srcdir;
 	
-	if (argv && argv[0] != NULL)
-		grind->symtab = load_symtab (argv[0]);
-	
 	/* now construct the UI */
 	gnome_app_create_menus_with_data ((GnomeApp *) grind, alleyoop_menu, grind);
 	
@@ -736,7 +714,6 @@ alleyoop_new (const char *tool, const char **argv, const char **srcdir)
 	grind->view = widget = vg_default_view_new ();
 	vg_tool_view_set_argv ((VgToolView *) widget, argv);
 	vg_tool_view_set_srcdir ((VgToolView *) widget, srcdir);
-	vg_tool_view_set_symtab ((VgToolView *) widget, grind->symtab);
 	gtk_widget_show (widget);
 	gnome_app_set_contents ((GnomeApp *) grind, widget);
 	
