@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  Alleyoop
- *  Copyright (C) 2003-2006 Jeffrey Stedfast
+ *  Copyright (C) 2003-2009 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -302,9 +302,8 @@ static int                                                              \
 strtoint##bits (const char *in, char **inend, int##bits##_t *retval, int *err)    \
 {                                                                       \
 	register const char *inptr = in;                                \
-	register size_t digit;                                          \
 	int##bits##_t val = 0;                                          \
-	int sign = 1;                                                   \
+	int digit, sign = 1;						\
 	                                                                \
 	while (*inptr == ' ')                                           \
 		inptr++;                                                \
@@ -370,8 +369,8 @@ static int                                                              \
 strtouint##bits (const char *in, char **inend, uint##bits##_t *retval, int *err)  \
 {                                                                       \
 	register const char *inptr = in;                                \
-	register size_t digit;                                          \
 	uint##bits##_t val = 0;                                         \
+	int digit;							\
 	                                                                \
 	while (*inptr == ' ')                                           \
 		inptr++;                                                \
@@ -383,7 +382,7 @@ strtouint##bits (const char *in, char **inend, uint##bits##_t *retval, int *err)
 			*err = EOVERFLOW;                               \
 			return -1;                                      \
 		} else if (val == (max / 10) && digit > (max % 10)) {   \
-		       	*err = EOVERFLOW;                               \
+			*err = EOVERFLOW;                               \
 			return -1;                                      \
 		} else {                                                \
 			val = (val * 10) + digit;                       \
@@ -619,6 +618,9 @@ getopts_get_next_opt (GetOptsContext *ctx)
 				
 				return GETOPTS_ERROR_BAD_OPTION;
 			}
+			
+			if (ctx->argindex > ctx->index)
+				ctx->index = ctx->argindex;
 		} else if (ctx->flags & GETOPTS_FLAG_BREAK_ON_FIRST_NONARG) {
 			break;
 		} else {
@@ -725,7 +727,7 @@ getopts_get_next_index (GetOptsContext *ctx)
 }
 
 
-char **
+const char **
 getopts_get_args (GetOptsContext *ctx, int *nargs)
 {
 	int i, n;
@@ -739,7 +741,7 @@ getopts_get_args (GetOptsContext *ctx, int *nargs)
 	if (nargs)
 		*nargs = n;
 	
-	return ctx->args;
+	return (const char **) ctx->args;
 }
 
 
@@ -895,7 +897,7 @@ int main (int argc, char **argv)
 	printf ("- float value was %f\n", fpnum);
 	printf ("- double value was %f\n", dpnum);
 	
-	getopts_context_free (ctx);
+	getopts_context_free (ctx, 1);
 	
 	return 0;
 }
