@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  Alleyoop
- *  Copyright (C) 2003-2006 Jeffrey Stedfast
+ *  Copyright (C) 2003-2009 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -55,7 +55,7 @@ struct _ElfDesc {
 static char *elf_class[ELFCLASSNUM] = {
 	"Invalid class",
 	"32-bit objects",
-	"64-but objects"
+	"64-bit objects"
 };
 
 static char *elf_data[ELFDATANUM] = {
