@@ -183,7 +183,7 @@ int main (int argc, char **argv)
 	GtkWidget *alleyoop;
 	const char **args;
 	char *srcdir_env;
-	int i;
+	int i, n;
 	
 #ifdef ENABLE_NLS
 	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
@@ -199,7 +199,11 @@ int main (int argc, char **argv)
 	
 	ctx = getopts_context_new (argc, argv, options, GETOPTS_FLAG_ALLOW_SINGLE_DASH | GETOPTS_FLAG_BREAK_ON_FIRST_NONARG);
 	getopts_parse_args (ctx);
-	args = getopts_get_args (ctx, NULL);
+	args = getopts_get_args (ctx, &n);
+	
+	/* if there are no args, set args to NULL so that the Run command will prompt. */
+	if (n == 0)
+		args = NULL;
 	
 	program = gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE, argc, argv,
 				      GNOME_PARAM_HUMAN_READABLE_NAME, _("Alleyoop"),
