@@ -188,28 +188,33 @@ static void
 set_search (VgDefaultView *view, int item_id, const char *expr)
 {
 	GtkWidget *parent, *dialog;
-	size_t size;
-	char *err;
-	int ret;
+	GError *err = NULL;
 	
-	if (view->search_id != SEARCH_ID_NONE)
-		regfree (&view->search_regex);
+	if (view->search_regex != NULL) {
+		g_regex_unref (view->search_regex);
+		view->search_regex = NULL;
+	}
 	
 	view->search_id = item_id;
 	if (item_id == SEARCH_ID_NONE)
 		return;
 	
-	if ((ret = regcomp (&view->search_regex, expr, REG_EXTENDED | REG_NOSUB)) == 0)
+#define COMPILE_FLAGS (G_REGEX_CASELESS | G_REGEX_EXTENDED | G_REGEX_OPTIMIZE)
+	view->search_regex = g_regex_new (expr, COMPILE_FLAGS, 0, &err);
+#undef COMPILE_FLAGS
+	
+	if (err == NULL) {
+		/* all is good in the world... */
 		return;
+	}
 	
 	/* regex compilation failed */
 	view->search_id = SEARCH_ID_NONE;
 	
-	size = regerror (ret, &view->search_regex, NULL, 0);
-	err = g_malloc (size);
-	regerror (ret, &view->search_regex, err, size);
-	
-	regfree (&view->search_regex);
+	if (view->search_regex != NULL) {
+		g_regex_unref (view->search_regex);
+		view->search_regex = NULL;
+	}
 	
 	parent = gtk_widget_get_toplevel ((GtkWidget *) view);
 	parent = GTK_WIDGET_TOPLEVEL (parent) ? parent : NULL;
@@ -217,9 +222,8 @@ set_search (VgDefaultView *view, int item_id, const char *expr)
 	dialog = gtk_message_dialog_new ((GtkWindow *) parent,
 					 GTK_DIALOG_DESTROY_WITH_PARENT,
 					 GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
-					 _("Invalid regular expression: '%s': %s"),
-					 expr, err);
-	g_free (err);
+					 "%s", err->message);
+	g_error_free (err);
 	
 	gtk_dialog_run ((GtkDialog *) dialog);
 	gtk_widget_destroy (dialog);
@@ -253,6 +257,7 @@ vg_default_view_init (VgDefaultView *view)
 	view->suppressions = g_ptr_array_new ();
 	view->errors = g_ptr_array_new ();
 	view->search_id = SEARCH_ID_NONE;
+	view->search_regex = NULL;
 	view->parser = NULL;
 	view->rules_id = 0;
 	view->srclines = 0;
@@ -311,8 +316,10 @@ vg_default_view_finalize (GObject *obj)
 		view->parser = NULL;
 	}
 	
-	if (view->search_id != SEARCH_ID_NONE)
-		regfree (&view->search_regex);
+	if (view->search_regex != NULL) {
+		g_regex_unref (view->search_regex);
+		view->search_regex = NULL;
+	}
 	
 	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
@@ -423,7 +430,7 @@ view_show_error (VgDefaultView *view, GtkTreeStore *model, VgError *err)
 			
 			if (stack->type != VG_STACK_EMPTY) {
 				g_string_append (str, " [");
-			
+				
 				if (stack->type == VG_STACK_SOURCE) {
 					if (stack->info.src.filename) {
 						g_string_append (str, stack->info.src.filename);
@@ -472,7 +479,7 @@ view_show_error (VgDefaultView *view, GtkTreeStore *model, VgError *err)
 }
 
 static gboolean
-error_matches_search (VgError *err, int search_id, regex_t *regex)
+error_matches_search (VgError *err, int search_id, GRegex *regex)
 {
 	VgErrorSummary *summary;
 	VgErrorStack *stack;
@@ -485,7 +492,7 @@ error_matches_search (VgError *err, int search_id, regex_t *regex)
 	
 	summary = err->summary;
 	if (search_id == SEARCH_ID_ERROR) {
-		return regexec (regex, summary->report, 0, NULL, 0) == 0;
+		return g_regex_match (regex, summary->report, 0, NULL);
 	} else {
 		do {
 			stack = summary->frames;
@@ -506,7 +513,7 @@ error_matches_search (VgError *err, int search_id, regex_t *regex)
 					g_assert_not_reached ();
 				}
 				
-				if (str && regexec (regex, str, 0, NULL, 0) == 0)
+				if (str && g_regex_match (regex, str, 0, NULL))
 					return TRUE;
 				
 				stack = stack->next;
@@ -532,7 +539,7 @@ view_rebuild (VgDefaultView *view)
 	for (i = 0; i < view->errors->len; i++) {
 		VgError *err = view->errors->pdata[i];
 		
-		if (error_matches_search (err, view->search_id, &view->search_regex))
+		if (error_matches_search (err, view->search_id, view->search_regex))
 			view_show_error (view, model, err);
 	}
 }
@@ -557,7 +564,7 @@ recv_error_cb (VgErrorParser *parser, VgError *err, gpointer user_data)
 	
 	model = (GtkTreeStore *) gtk_tree_view_get_model ((GtkTreeView *) view->table);
 	
-	if (error_matches_search (err, view->search_id, &view->search_regex))
+	if (error_matches_search (err, view->search_id, view->search_regex))
 		view_show_error (view, model, err);
 }
 
