@@ -26,7 +26,6 @@
 #include <gconf/gconf-client.h>
 
 #include <sys/types.h>
-#include <regex.h>
 
 #include "vgtoolview.h"
 #include "vgerror.h"
@@ -59,8 +58,8 @@ struct _VgDefaultView {
 	
 	GPtrArray *suppressions;
 	
+	GRegex *search_regex;
 	int search_id;
-	regex_t search_regex;
 	
 	guint rules_id;
 	
