@@ -110,7 +110,7 @@ static char *
 decode_hex_value (const char *text)
 {
 	unsigned long int retval;
-	const char *inend;
+	char *inend;
 	
 	retval = strtoul (text, &inend, 16);
 	if (inend == text)
