@@ -44,6 +44,7 @@
 //#define ENABLE_FREE_FILL_KEY       "/apps/alleyoop/valgrind/memcheck/enable-free-fill"
 #define FREE_FILL_KEY              "/apps/alleyoop/valgrind/memcheck/free-fill"
 #define WORKAROUND_GCC296_BUGS_KEY "/apps/alleyoop/valgrind/memcheck/workaround-gcc296-bugs"
+#define TRACK_ORIGINS_KEY          "/apps/alleyoop/valgrind/memcheck/track-origins"
 
 static void vg_memcheck_prefs_class_init (VgMemcheckPrefsClass *klass);
 static void vg_memcheck_prefs_init (VgMemcheckPrefs *prefs);
@@ -408,6 +409,15 @@ vg_memcheck_prefs_init (VgMemcheckPrefs *prefs)
 	gtk_box_pack_start ((GtkBox *) vbox, hbox, FALSE, FALSE, 0);
 	g_free (str);
 	
+	/* --track-origins */
+	bool = gconf_client_get_bool (gconf, TRACK_ORIGINS_KEY, NULL);
+	widget = gtk_check_button_new_with_label (_("Track origins of undefined values"));
+	g_signal_connect (widget, "toggled", G_CALLBACK (toggle_button_toggled), TRACK_ORIGINS_KEY);
+	gtk_toggle_button_set_active ((GtkToggleButton *) widget, bool);
+	prefs->track_origins = (GtkToggleButton *) widget;
+	gtk_widget_show (widget);
+	gtk_box_pack_start ((GtkBox *) vbox, widget, FALSE, FALSE, 0);
+	
 	/* --workaround-gcc296-bugs */
 	bool = gconf_client_get_bool (gconf, WORKAROUND_GCC296_BUGS_KEY, NULL);
 	widget = gtk_check_button_new_with_label (_("Work around bugs generated by gcc 2.96"));
@@ -467,6 +477,7 @@ static struct {
 	{ IGNORE_RANGES_KEY,          "--ignore-ranges",          MEMCHECK, NULL, ARG_TYPE_STRING, 0       },
 	{ MALLOC_FILL_KEY,            "--malloc-fill",            MEMCHECK, NULL, ARG_TYPE_STRING, 0       },
 	{ FREE_FILL_KEY,              "--free-fill",              MEMCHECK, NULL, ARG_TYPE_STRING, 0       },
+	{ TRACK_ORIGINS_KEY,          "--track-origins",          MEMCHECK, NULL, ARG_TYPE_BOOL,   0,      },
 	{ WORKAROUND_GCC296_BUGS_KEY, "--workaround-gcc296-bugs", BOTH,     NULL, ARG_TYPE_BOOL,   0       },
 };
 
