@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  Alleyoop
- *  Copyright (C) 2003-2006 Jeffrey Stedfast
+ *  Copyright (C) 2003-2009 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -103,7 +103,6 @@ static void
 vg_tool_view_init (VgToolView *view)
 {
 	view->argv = NULL;
-	view->symtab = NULL;
 	view->srcdir = NULL;
 	view->rules = NULL;
 }
@@ -139,15 +138,6 @@ vg_tool_view_set_srcdir (VgToolView *view, const char **srcdir)
 }
 
 
-void
-vg_tool_view_set_symtab (VgToolView *view, SymTab *symtab)
-{
-	g_return_if_fail (VG_IS_TOOL_VIEW (view));
-	
-	view->symtab = symtab;
-}
-
-
 static void
 tool_view_clear (VgToolView *view)
 {
